Generate a random vector of number of children.
children(
n,
x = 0:10,
prob = c(0.25, 0.25, 0.15, 0.15, 0.1, 0.02, 0.02, 0.02, 0.02, 0.01, 0.01),
name = "Children"
)Returns a random vector of number of children elements.
The number elements to generate. This can be globally set within
the environment of r_data_frame or r_list.
A vector of elements to chose from.
A vector of probabilities to chose from.
The name to assign to the output vector's varname
attribute. This is used to auto assign names to the column/vector name when
used inside of r_data_frame or r_list.
Other variable functions:
age(),
animal(),
answer(),
area(),
car(),
coin(),
color(),
date_stamp(),
death(),
dice(),
dna(),
dob(),
dummy(),
education(),
employment(),
eye(),
grade(),
grade_level(),
group(),
hair(),
height(),
income(),
internet_browser(),
iq(),
language,
level(),
likert(),
lorem_ipsum(),
marital(),
military(),
month(),
name,
normal(),
political(),
race(),
religion(),
sat(),
sentence(),
sex(),
sex_inclusive(),
smokes(),
speed(),
state(),
string(),
upper(),
valid(),
year(),
zip_code()
children(10)
pie(table(children(100)))
Run the code above in your browser using DataLab