Learn R Programming

wakefield (version 0.3.9)

income: Generate Random Gamma Vector of Incomes

Description

Generate a random gamma vector of incomes.

Usage

income(n, digits = 2, name = "Income")

Value

Returns a random gamma vector of income elements.

Arguments

n

The number elements to generate. This can be globally set within the environment of r_data_frame or r_list.

digits

Integer indicating the number of decimal places to be used. Negative values are allowed (see round).

name

The name to assign to the output vector's varname attribute. This is used to auto assign names to the column/vector name when used inside of r_data_frame or r_list.

Details

Incomes are generated using: rgamma(n, 2) * 2000.

See Also

gamma

Other variable functions: age(), animal(), answer(), area(), car(), children(), coin(), color(), date_stamp(), death(), dice(), dna(), dob(), dummy(), education(), employment(), eye(), grade(), grade_level(), group(), hair(), height(), internet_browser(), iq(), language, level(), likert(), lorem_ipsum(), marital(), military(), month(), name, normal(), political(), race(), religion(), sat(), sentence(), sex(), sex_inclusive(), smokes(), speed(), state(), string(), upper(), valid(), year(), zip_code()

Examples

Run this code
income(10)
hist(income(10000))
pie(table(cut(income(10000), 10)))

Run the code above in your browser using DataLab