Learn R Programming

wakefield (version 0.3.9)

military: Generate Random Vector of Military Branches

Description

Generate a random vector of military branches.

Usage

military(
  n,
  x = c("Army", "Air Force", "Navy", "Marine Corps", "Coast Guard"),
  prob = c(0.3785, 0.2334, 0.2218, 0.1366, 0.0296),
  name = "Military"
)

Value

Returns a random factor vector of military branch elements.

Arguments

n

The number elements to generate. This can be globally set within the environment of r_data_frame or r_list.

x

A vector of elements to chose from.

prob

A vector of probabilities to chose from.

name

The name to assign to the output vector's varname attribute. This is used to auto assign names to the column/vector name when used inside of r_data_frame or r_list.

Details

The military branches and probabilities used match approximate U.S. military make-up:

BranchNPercent
Army541,29137.9%
Air Force333,77223.3%
Navy317,23722.2%
Marine Corps195,33813.7%
Coast Guard42,3573.0%

See Also

Other variable functions: age(), animal(), answer(), area(), car(), children(), coin(), color(), date_stamp(), death(), dice(), dna(), dob(), dummy(), education(), employment(), eye(), grade(), grade_level(), group(), hair(), height(), income(), internet_browser(), iq(), language, level(), likert(), lorem_ipsum(), marital(), month(), name, normal(), political(), race(), religion(), sat(), sentence(), sex(), sex_inclusive(), smokes(), speed(), state(), string(), upper(), valid(), year(), zip_code()

Examples

Run this code
military(10)
barplot(table(military(10000)))
pie(table(military(10000)))

Run the code above in your browser using DataLab