Learn R Programming

wakefield (version 0.3.9)

minute: Generate a Random Sequence of Minutes in H:M:S Format

Description

Generate a random vector of minutes in H:M:S format.

Usage

minute(
  n,
  x = seq(0, 59, by = 1)/60,
  prob = NULL,
  random = FALSE,
  name = "Minute"
)

Value

Returns a random vector of minute time elements in H:M:S format.

Arguments

n

The number elements to generate. This can be globally set within the environment of r_data_frame or r_list.

x

A vector of elements to chose from.

prob

A vector of probabilities to chose from.

random

logical. If TRUE the times are randomized, otherwise the times are sequential.

name

The name to assign to the output vector's varname attribute. This is used to auto assign names to the column/vector name when used inside of r_data_frame or r_list.

See Also

times

Examples

Run this code
minute(20)
minute(20, random=TRUE)
pie(table(minute(2000, x = seq(0, 59, by = 10)/60, prob = probs(6))))

Run the code above in your browser using DataLab