| normal | R Documentation |
normal - A wrapper for rnorm that generate a
random normal vector.
normal_round - A wrapper for rnorm that generate
a rounded random normal vector.
normal(n, mean = 0, sd = 1, min = NULL, max = NULL, name = "Normal")
normal_round(
n,
mean = 0,
sd = 1,
min = NULL,
max = NULL,
digits = 2,
name = "Normal"
)
n |
The number elements to generate. This can be globally set within
the environment of |
mean |
The mean value for the normal distribution to be drawn from. |
sd |
The standard deviation of the normal distribution to draw from. |
min |
A numeric lower boundary cutoff. Results less than this value will be
replaced with |
max |
A numeric upper boundary cutoff. Results greater than this value will
be replaced with |
name |
The name to assign to the output vector's |
digits |
Integer indicating the number of decimal places to be used.
Negative values are allowed (see |
Returns a random vector of elements.
rnorm
round
Other variable functions:
age(),
animal(),
answer(),
area(),
car(),
children(),
coin(),
color(),
date_stamp(),
death(),
dice(),
dna(),
dob(),
dummy(),
education(),
employment(),
eye(),
grade(),
grade_level(),
group(),
hair(),
height(),
income(),
internet_browser(),
iq(),
language,
level(),
likert(),
lorem_ipsum(),
marital(),
military(),
month(),
name,
political(),
race(),
religion(),
sat(),
sentence(),
sex(),
sex_inclusive(),
smokes(),
speed(),
state(),
string(),
upper(),
valid(),
year(),
zip_code()
normal(100, name = "Var")
hist(normal(10000, 100, 10))
interval(normal, 9, n = 1000)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.