Learn R Programming

wakefield (version 0.3.9)

r_dummy: Generate Random Dummy Values

Description

Generate random values from a wakefield variable function.

Usage

r_dummy(fun, n, ..., prefix = FALSE, rep.sep = "_")

Value

Returns a as_tibble.

Arguments

fun

A wakefield variable function.

n

The number of rows to produce.

prefix

logical. If TRUE the original factor name (supplied to fun as name argument) will prefix the column names that were generated from the factor's categories.

rep.sep

A separator to use for the variable and category part of names when prefix = TRUE. For example if the age is used (r_dummy(sex)), this results in column names c("Sex_Male", "Sex_Female").

...

Additional arguments passed to fun.

See Also

r_list, r_data_frame, r_series

Examples

Run this code
r_dummy(sex, 10)
r_dummy(race, 1000)
r_dummy(race, 1000, name = "Ethnicity")

Run the code above in your browser using DataLab