Learn R Programming

wakefield (version 0.3.9)

time_stamp: Generate a Random Sequence of Times in H:M:S Format

Description

Generate a random vector of times in H:M:S format.

Usage

time_stamp(
  n,
  x = seq(0, 23, by = 1),
  prob = NULL,
  random = FALSE,
  name = "Time"
)

Value

Returns a random vector of time elements in H:M:S format.

Arguments

n

The number elements to generate. This can be globally set within the environment of r_data_frame or r_list.

x

A vector of elements to chose from.

prob

A vector of probabilities to chose from.

random

logical. If TRUE the times are randomized, otherwise the times are sequential.

name

The name to assign to the output vector's varname attribute. This is used to auto assign names to the column/vector name when used inside of r_data_frame or r_list.

See Also

times

Examples

Run this code
time_stamp(20)
time_stamp(20, random=TRUE)
pie(table(time_stamp(2000, x = seq(0, 23, by = 2), prob = probs(12))))

Run the code above in your browser using DataLab