animal - Generate a random vector of animals.
pet - Generate a random vector of pets.
animal(n, k = 10, x = wakefield::animal_list, prob = NULL, name = "Animal")pet(
n,
x = c("Dog", "Cat", "None", "Bird", "Horse"),
prob = c(0.365, 0.304, 0.258, 0.031, 0.015),
name = "Pet"
)
Returns a random factor vector of animal elements.
The number elements to generate. This can be globally set within
the environment of r_data_frame or r_list.
The number of the elements of x to sample from (uses sample(x, k)).
A vector of elements to chose from.
A vector of probabilities to chose from.
The name to assign to the output vector's varname
attribute. This is used to auto assign names to the column/vector name when
used inside of r_data_frame or r_list.
The household pets and probabilities:
| Dog | 36.5 % |
| Cat | 30.4 % |
| None | 25.8 % |
| Bird | 3.1 % |
| Horse | 1.5 % |
Other variable functions:
age(),
answer(),
area(),
car(),
children(),
coin(),
color(),
date_stamp(),
death(),
dice(),
dna(),
dob(),
dummy(),
education(),
employment(),
eye(),
grade(),
grade_level(),
group(),
hair(),
height(),
income(),
internet_browser(),
iq(),
language,
level(),
likert(),
lorem_ipsum(),
marital(),
military(),
month(),
name,
normal(),
political(),
race(),
religion(),
sat(),
sentence(),
sex(),
sex_inclusive(),
smokes(),
speed(),
state(),
string(),
upper(),
valid(),
year(),
zip_code()
animal(10)
pie(table(animal(10000)))
pet(10)
pie(table(pet(10000)))
Run the code above in your browser using DataLab