Generate a random vector of military branches.
military(
n,
x = c("Army", "Air Force", "Navy", "Marine Corps", "Coast Guard"),
prob = c(0.3785, 0.2334, 0.2218, 0.1366, 0.0296),
name = "Military"
)Returns a random factor vector of military branch elements.
The number elements to generate. This can be globally set within
the environment of r_data_frame or r_list.
A vector of elements to chose from.
A vector of probabilities to chose from.
The name to assign to the output vector's varname
attribute. This is used to auto assign names to the column/vector name when
used inside of r_data_frame or r_list.
The military branches and probabilities used match approximate U.S. military make-up:
| Branch | N | Percent |
| Army | 541,291 | 37.9% |
| Air Force | 333,772 | 23.3% |
| Navy | 317,237 | 22.2% |
| Marine Corps | 195,338 | 13.7% |
| Coast Guard | 42,357 | 3.0% |
Other variable functions:
age(),
animal(),
answer(),
area(),
car(),
children(),
coin(),
color(),
date_stamp(),
death(),
dice(),
dna(),
dob(),
dummy(),
education(),
employment(),
eye(),
grade(),
grade_level(),
group(),
hair(),
height(),
income(),
internet_browser(),
iq(),
language,
level(),
likert(),
lorem_ipsum(),
marital(),
month(),
name,
normal(),
political(),
race(),
religion(),
sat(),
sentence(),
sex(),
sex_inclusive(),
smokes(),
speed(),
state(),
string(),
upper(),
valid(),
year(),
zip_code()
military(10)
barplot(table(military(10000)))
pie(table(military(10000)))
Run the code above in your browser using DataLab